expect_message_struct

Function expect_message_struct 

pub fn expect_message_struct(r: &mut TlvReader<'_>) -> Result<(), ImError>
Assert the reader’s first element is an anonymous message struct and consume its start.

Errors

Returns error::ImError::NotAStruct if the first element is not an anonymous structure start, or propagates any error::ImError::Codec error from the reader.