parse_invoke_request

Function parse_invoke_request 

pub fn parse_invoke_request(
    bytes: &[u8],
) -> Result<ParsedInvokeRequest, ImError>
Parse an inbound InvokeRequestMessage (Matter Core 10.7) — the message a device sends to a server (e.g. a Requestor’s QueryImage to an OTA Provider).

Errors

Returns crate::ImError if the message is not a struct or lacks the InvokeRequests array, or a CommandDataIB lacks a CommandPath.