Module status

Module status 

Interaction Model status codes — Matter Core Spec 8.10 (Status Codes).

Enums

ImStatus
An Interaction Model status, as carried by a StatusIB.

Functions

parse_status_response
Parse a bare StatusResponseMessage ({ 0: Status (u8), 0xFF: IMRev }) into its status code, or None if the message is not a bare status response.